From 3728180233eea251b2cca9051d5c2c002c7cd204 Mon Sep 17 00:00:00 2001
From: ralfulrich <ralf.ulrich@kit.edu>
Date: Mon, 25 Jan 2021 08:15:46 +0100
Subject: [PATCH] added Felix suggestions

---
 tests/modules/testPythia8.cpp | 9 ++++++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/tests/modules/testPythia8.cpp b/tests/modules/testPythia8.cpp
index 4f93280f5..8ddd613ad 100644
--- a/tests/modules/testPythia8.cpp
+++ b/tests/modules/testPythia8.cpp
@@ -157,9 +157,11 @@ TEST_CASE("pythia process") {
 
   SECTION("pythia interaction") {
 
-    // feenableexcept(FE_INVALID); \todo how does this work nowadays
+    //! feenableexcept(FE_INVALID); \todo how does this work nowadays
+
+    // this will be a p-p collision at sqrts=3.5TeV -> no problem for pythia
     auto [stackPtr, secViewPtr] = setup::testing::setup_stack(
-        Code::PiPlus, 0, 0, 100_GeV, (setup::Environment::BaseNodeType* const)nodePtr,
+        Code::Proton, 0, 0, 7_TeV, (setup::Environment::BaseNodeType* const)nodePtr,
         *csPtr);
     auto& view = *secViewPtr;
     auto particle = stackPtr->first();
@@ -167,6 +169,7 @@ TEST_CASE("pythia process") {
     corsika::pythia8::Interaction model;
     model.doInteraction(view);
     [[maybe_unused]] const GrammageType length = model.getInteractionLength(particle);
-    CHECK(length / 1_kg * square(1_m) == Approx(82.2524));
+    CHECK(length / 1_kg * square(1_m) == Approx(43.04).margin(5e-1));
+    CHECK(view.getSize() == 38);
   }
 }
-- 
GitLab